# Copyright (c) by it's authors. 
# Some rights reserved. See LICENSE, AUTHORS.

from setuptools import setup, find_packages
 
setup(name='$appname$',
      version='0.1',
      url='<url>',
      author='<author>',
      author_email='<mail>',
      packages=find_packages('.'),
      install_requires=['wallaby-app-inspector'],
      include_package_data = True
  )
